@@ -332,15 +332,30 @@ def edit_config(model_selected, config_output_dir, num_steps, label_map_path, re
     print(f"Configuration successfully edited and saved at {config_output_dir}")
 
 
-def train(ckpt_dir='', config_path='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
+def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
           record_summaries=True):
 
+    if config.endswith('.config')
+        if not os.path.isfile(config):
+            raise FileNotFoundError('No config file found at {}'.format(config)) 
+    else:
+        if os.path.isdir(config):
+            files = os.listdir(config)
+            file_found = False
+            for f in files:
+                if not file_found:
+                    if f.endswith('.config'):
+                        config = f 
+                        file_found = True 
+    if not file_found:
+        raise FileNotFoundError('No config file found in this directory {}'.format(config))
+
     tf.config.set_soft_device_placement(True)
     strategy = tf.compat.v2.distribute.MirroredStrategy()
 
     with strategy.scope():
       model_lib_v2.train_loop(
-          pipeline_config_path=config_path,
+          pipeline_config_path=config,
           model_dir=ckpt_dir,
           train_steps=train_steps,
           use_tpu=use_tpu,
@@ -446,14 +461,14 @@ def train(ckpt_dir='', config_path='', train_steps=1000, use_tpu=False, checkpoi
 #         ckpt_dir,
 #         graph_hook_fn=graph_rewriter_fn)
 
-def evaluate(metrics_dir='', config_path='', ckpt_dir=''):
+def evaluate(metrics_dir='', config='', ckpt_dir=''):
     '''
         Function used to evaluate your trained model. 
 
         Args: 
             Required:               
                 eval_dir: The directory where the tfevent file will be saved.
-                config_dir: The protobuf configuration directory.
+                config: The protobuf configuration file or directory.
                 checkpoint_dir: The directory where the checkpoint you want to evaluate is.
             
             Optional:
@@ -462,9 +477,24 @@ def evaluate(metrics_dir='', config_path='', ckpt_dir=''):
         Returns:
             A dictionnary of metrics ready to be sent to the picsell.ia platform.
     '''
+    if config.endswith('.config')
+        if not os.path.isfile(config):
+            raise FileNotFoundError('No config file found at {}'.format(config)) 
+    else:
+        if os.path.isdir(config):
+            files = os.listdir(config)
+            file_found = False
+            for f in files:
+                if not file_found:
+                    if f.endswith('.config'):
+                        config = f 
+                        file_found = True 
+    if not file_found:
+        raise FileNotFoundError('No config file found in this directory {}'.format(config))
+
     tf.config.set_soft_device_placement(True)
     model_lib_v2.eval_continuously(
-        pipeline_config_path=config_path,
+        pipeline_config_path=config,
         model_dir=metrics_dir,
         train_steps=None,
         sample_1_of_n_eval_examples=1,
@@ -477,12 +507,26 @@ def tf_events_to_dict(path, type=''):
     '''Get a dictionnary of scalars from the tfevent inside the training directory.
 
         Args: 
-            path: The path to the training directory where a tfevent file is saved.
+            path: The path to the directory where a tfevent file is saved or the path to the file.
         
         Returns:
             A dictionnary of scalars logs.
     '''
     log_dict = {}
+    if path.startswith('events.out')
+        if not os.path.isfile(path):
+            raise FileNotFoundError('No tfEvent file found at {}'.format(path)) 
+    else:
+        if os.path.isdir(path):
+            files = os.listdir(path)
+            file_found = False
+            for f in files:
+                if not file_found:
+                    if f.startswith('events.out'):
+                        path = f 
+                        file_found = True 
+    if not file_found:
+        raise FileNotFoundError('No tfEvent file found in this directory {}'.format(path))
     for summary in summary_iterator(path):
         for v in summary.summary.value:
             if not 'image' in v.tag:
@@ -522,7 +566,7 @@ def export_graph(ckpt_dir, exported_model_dir, pipeline_config_dir,
         side_input_types, side_input_names)
         
 
-def run_inference(path, exported_model_dir, label_map_path, results_dir, disp=True, num_infer=5, min_score_thresh=0.7, from_tfrecords=False):
+def infer(path, exported_model_dir, label_map_path, results_dir, disp=True, num_infer=5, min_score_thresh=0.7, from_tfrecords=False):
     ''' Use your exported model to infer on a path list of images. 
 
         Args:
